==> AGXUnreal-1.17.0_UE-5.6_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Math/Matrix3x3.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Math/MathForward.h>
/* Generated code for model Matrix3x3 */
namespace openplx::Math {
    class Matrix3x3 : public openplx::Core::Object {
        protected:
            double m_e00;
            double m_e01;
            double m_e02;
            double m_e10;
            double m_e11;
            double m_e12;
            double m_e20;
            double m_e21;
            double m_e22;

        public:
            Matrix3x3();
            double e00() const;
            double e01() const;
            double e02() const;
            double e10() const;
            double e11() const;
            double e12() const;
            double e20() const;
            double e21() const;
            double e22() const;
            static std::shared_ptr<openplx::Math::Matrix3x3> from_row_major(double r0c0, double r0c1, double r0c2, double r1c0, double r1c1, double r1c2, double r2c0, double r2c1, double r2c2);
            static std::shared_ptr<openplx::Math::Matrix3x3> from_rows(std::vector<double> r0, std::vector<double> r1, std::vector<double> r2);
            static std::shared_ptr<openplx::Math::Matrix3x3> from_columns(std::vector<double> c0, std::vector<double> c1, std::vector<double> c2);
            static std::shared_ptr<openplx::Math::Matrix3x3> diag(double x, double y, double z);
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.7_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Math/Matrix3x3.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Math/MathBundleExport.h>
#include <openplx/Math/MathForward.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model Matrix3x3 */
namespace openplx::Math {
    class OPENPLX_Math_BUNDLE_EXPORT Matrix3x3 : public openplx::Core::Object {
        protected:
            double m_e00;
            double m_e01;
            double m_e02;
            double m_e10;
            double m_e11;
            double m_e12;
            double m_e20;
            double m_e21;
            double m_e22;

        public:
            Matrix3x3();
            virtual ~Matrix3x3();
            double e00() const;
            double e01() const;
            double e02() const;
            double e10() const;
            double e11() const;
            double e12() const;
            double e20() const;
            double e21() const;
            double e22() const;
            static std::shared_ptr<openplx::Math::Matrix3x3> from_row_major(double r0c0, double r0c1, double r0c2, double r1c0, double r1c1, double r1c2, double r2c0, double r2c1, double r2c2);
            static std::shared_ptr<openplx::Math::Matrix3x3> from_rows(std::vector<double> r0, std::vector<double> r1, std::vector<double> r2);
            static std::shared_ptr<openplx::Math::Matrix3x3> from_columns(std::vector<double> c0, std::vector<double> c1, std::vector<double> c2);
            static std::shared_ptr<openplx::Math::Matrix3x3> diag(double x, double y, double z);
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
